==> com.idenfy.idenfySdk-1.1.3.2-sources.jar: com/idenfy/idenfySdk/UI/DocumentPhotoResultView/DocumentPhotoResult.kt <==
package com.idenfy.idenfySdk.UI.DocumentPhotoResultView

import android.graphics.Bitmap

import com.idenfy.idenfySdk.Models.Step
import com.idenfy.idenfySdk.helpers.enums.UploadDocumentPhotoType

class DocumentPhotoResult {
    var documentImage: Bitmap? = null
    var currentDocumentStep: Step? = null
    var uploadPhotoType: UploadDocumentPhotoType? = null
    var rectangleRight: Int?=null
    var rectangleLeft: Int?=null
    var rectangleTop: Int?=null;
    var rectangleBottom: Int? = null;



    constructor(documentImage: Bitmap?) {
        this.documentImage = documentImage
    }

    constructor(documentImage: Bitmap?, uploadPhotoType: UploadDocumentPhotoType?) {
        this.documentImage = documentImage
        this.uploadPhotoType = uploadPhotoType
    }

    constructor(documentImage: Bitmap?, currentDocumentStep: Step?, uploadPhotoType: UploadDocumentPhotoType?) {
        this.documentImage = documentImage
        this.currentDocumentStep = currentDocumentStep
        this.uploadPhotoType = uploadPhotoType
    }

    constructor(documentImage: Bitmap?, currentDocumentStep: Step?, uploadPhotoType: UploadDocumentPhotoType?, rectangleRight: Int?, rectangleLeft: Int?, rectangleTop: Int?, rectangleBottom: Int?) {
        this.documentImage = documentImage
        this.currentDocumentStep = currentDocumentStep
        this.uploadPhotoType = uploadPhotoType
        this.rectangleRight = rectangleRight
        this.rectangleLeft = rectangleLeft
        this.rectangleTop = rectangleTop
        this.rectangleBottom = rectangleBottom
    }

}

==> com.idenfy.idenfySdk-1.1.5.4-sources.jar: com/idenfy/idenfySdk/UI/DocumentPhotoResultView/DocumentPhotoResult.kt <==
package com.idenfy.idenfySdk.UI.DocumentPhotoResultView

import android.graphics.Bitmap
import android.util.Log
import com.idenfy.idenfySdk.CoreSdkInitialization.IdenfyController
import com.idenfy.idenfySdk.CoreSdkInitialization.IdenfySettings

import com.idenfy.idenfySdk.Models.Step
import com.idenfy.idenfySdk.helpers.enums.AuthentificationResult
import com.idenfy.idenfySdk.helpers.enums.UploadDocumentPhotoType

class DocumentPhotoResult {
    var documentImage: Bitmap? = null
    var currentDocumentStep: Step? = null
    var uploadPhotoType: UploadDocumentPhotoType? = null
    var rectangleRight: Int? = null
    var rectangleLeft: Int? = null
    var rectangleTop: Int? = null;
    var rectangleBottom: Int? = null;


    constructor(documentImage: Bitmap?) {
        this.documentImage = documentImage
    }

    constructor(documentImage: Bitmap?, uploadPhotoType: UploadDocumentPhotoType?) {
        this.documentImage = documentImage
        this.uploadPhotoType = uploadPhotoType
    }

    constructor(documentImage: Bitmap?, currentDocumentStep: Step?, uploadPhotoType: UploadDocumentPhotoType?) {
        this.documentImage = documentImage
        this.currentDocumentStep = currentDocumentStep
        this.uploadPhotoType = uploadPhotoType
    }

    constructor(documentImage: Bitmap?, currentDocumentStep: Step?, uploadPhotoType: UploadDocumentPhotoType?, rectangleRight: Int?, rectangleLeft: Int?, rectangleTop: Int?, rectangleBottom: Int?) {
        this.documentImage = documentImage
        this.currentDocumentStep = currentDocumentStep
        this.uploadPhotoType = uploadPhotoType
        this.rectangleRight = rectangleRight
        this.rectangleLeft = rectangleLeft
        this.rectangleTop = rectangleTop
        this.rectangleBottom = rectangleBottom

    }

}
